@@ -8,20 +8,18 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <unistd.h>
-#include <glib-object.h>
-#include <glib/gi18n.h>
-#include <glib/gprintf.h>
-#include <cairo-gobject.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 #include "process-tree-model.h"
 #include "process-tree-view.h"
-#include "task-manager.h"
 #include "settings.h"
+#include "task-manager.h"
+
+#include <cairo-gobject.h>
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
+#include <glib/gprintf.h>
 
 
 
@@ -33,9 +31,12 @@ enum
 	COLUMN_PPID,
 	COLUMN_STATE,
 	COLUMN_VSZ,
+	COLUMN_GROUP_VSZ,
 	COLUMN_RSS,
+	COLUMN_GROUP_RSS,
 	COLUMN_UID,
 	COLUMN_CPU,
+	COLUMN_GROUP_CPU,
 	COLUMN_PRIORITY,
 	N_COLUMNS,
 };
@@ -43,38 +44,38 @@ enum
 typedef struct _XtmProcessTreeViewClass XtmProcessTreeViewClass;
 struct _XtmProcessTreeViewClass
 {
-	GtkTreeViewClass	parent_class;
+	GtkTreeViewClass parent_class;
 };
 struct _XtmProcessTreeView
 {
-	GtkTreeView		parent;
+	GtkTreeView parent;
 	/*<private>*/
-	GtkListStore *		model;
-	GtkTreeModel *		model_filter;
-	gchar *			cmd_filter;
-	GtkTreeModel *		model_tree;
-	GtkTreeViewColumn *	sort_column;
-	gushort			columns_positions[N_COLUMNS];
-	XtmSettings *		settings;
-	guint			owner_uid;
-	gboolean		show_all_processes_cached;
+	GtkListStore *model;
+	GtkTreeModel *model_filter;
+	gchar *cmd_filter;
+	GtkTreeModel *model_tree;
+	GtkTreeViewColumn *sort_column;
+	gushort columns_positions[N_COLUMNS];
+	XtmSettings *settings;
+	guint owner_uid;
+	gboolean show_all_processes_cached;
 };
 G_DEFINE_TYPE (XtmProcessTreeView, xtm_process_tree_view, GTK_TYPE_TREE_VIEW)
 
-static void		xtm_process_tree_view_finalize			(GObject *object);
+static void xtm_process_tree_view_finalize (GObject *object);
 
-static gboolean		treeview_clicked				(XtmProcessTreeView *treeview, GdkEventButton *event);
-static gboolean		treeview_key_pressed				(XtmProcessTreeView *treeview, GdkEventKey *event);
-static void		column_task_pack_cells				(XtmProcessTreeView *treeview, GtkTreeViewColumn *column);
-static void		columns_changed					(XtmProcessTreeView *treeview);
-static void		read_columns_positions				(XtmProcessTreeView *treeview);
-static void		save_columns_positions				(XtmProcessTreeView *treeview);
-static void		column_clicked					(GtkTreeViewColumn *column, XtmProcessTreeView *treeview);
-static gboolean		visible_func					(GtkTreeModel *model, GtkTreeIter *iter, XtmProcessTreeView *treeview);
-static gboolean		search_func					(GtkTreeModel *model, gint column, const gchar *key, GtkTreeIter *iter, gpointer user_data);
-static void		settings_changed				(GObject *object, GParamSpec *pspec, XtmProcessTreeView *treeview);
-static void		expand_row					(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, XtmProcessTreeView *treeview);
-static gboolean		treeview_query_tooltip		(GtkWidget *widget, gint x, gint y, gboolean keyboard_tip, GtkTooltip *tooltip, gpointer data);
+static gboolean treeview_clicked (XtmProcessTreeView *treeview, GdkEventButton *event);
+static gboolean treeview_key_pressed (XtmProcessTreeView *treeview, GdkEventKey *event);
+static void column_task_pack_cells (XtmProcessTreeView *treeview, GtkTreeViewColumn *column);
+static void columns_changed (XtmProcessTreeView *treeview);
+static void read_columns_positions (XtmProcessTreeView *treeview);
+static void save_columns_positions (XtmProcessTreeView *treeview);
+static void column_clicked (GtkTreeViewColumn *column, XtmProcessTreeView *treeview);
+static gboolean visible_func (GtkTreeModel *model, GtkTreeIter *iter, XtmProcessTreeView *treeview);
+static gboolean search_func (GtkTreeModel *model, gint column, const gchar *key, GtkTreeIter *iter, gpointer user_data);
+static void settings_changed (GObject *object, GParamSpec *pspec, XtmProcessTreeView *treeview);
+static void expand_row (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, XtmProcessTreeView *treeview);
+static gboolean treeview_query_tooltip (GtkWidget *widget, gint x, gint y, gboolean keyboard_tip, GtkTooltip *tooltip, gpointer data);
 
 static void
 xtm_process_tree_view_class_init (XtmProcessTreeViewClass *klass)
@@ -98,14 +99,34 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	g_object_get (treeview->settings, "show-all-processes", &treeview->show_all_processes_cached, "process-tree", &tree, NULL);
 
 	/* Create tree view model */
-#ifdef HAVE_WNCK
-	treeview->model = gtk_list_store_new (XTM_PTV_N_COLUMNS, CAIRO_GOBJECT_TYPE_SURFACE,
-#else
 	treeview->model = gtk_list_store_new (XTM_PTV_N_COLUMNS,
+#ifdef HAVE_WNCK
+		CAIRO_GOBJECT_TYPE_SURFACE, /* XTM_PTV_COLUMN_ICON */
 #endif
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT64,
-		G_TYPE_STRING, G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_FLOAT, G_TYPE_STRING, G_TYPE_INT,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_LONG);
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_COMMAND */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_COMMAND_RAW */
+		G_TYPE_UINT, /* XTM_PTV_COLUMN_PID */
+		G_TYPE_UINT, /* XTM_PTV_COLUMN_PPID */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_STATE */
+		G_TYPE_UINT64, /* XTM_PTV_COLUMN_VSZ */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_VSZ_STR */
+		G_TYPE_UINT64, /* XTM_PTV_COLUMN_GROUP_VSZ */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_GROUP_VSZ_STR */
+		G_TYPE_UINT64, /* XTM_PTV_COLUMN_RSS */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_RSS_STR */
+		G_TYPE_UINT64, /* XTM_PTV_COLUMN_GROUP_RSS */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_GROUP_RSS_STR */
+		G_TYPE_UINT, /* XTM_PTV_COLUMN_UID */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_UID_STR */
+		G_TYPE_FLOAT, /* XTM_PTV_COLUMN_CPU */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_CPU_STR */
+		G_TYPE_FLOAT, /* XTM_PTV_COLUMN_GROUP_CPU */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_GROUP_CPU_STR */
+		G_TYPE_INT, /* XTM_PTV_COLUMN_PRIORITY */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_BACKGROUND */
+		G_TYPE_STRING, /* XTM_PTV_COLUMN_FOREGROUND */
+		G_TYPE_LONG /* XTM_PTV_COLUMN_TIMESTAMP */
+	);
 
 	treeview->model_filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (treeview->model), NULL);
 	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (treeview->model_filter), (GtkTreeModelFilterVisibleFunc)visible_func, treeview, NULL);
@@ -122,7 +143,7 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	treeview->cmd_filter = NULL;
 
 	/* Create cell renderer for tree view columns */
-	cell_text = gtk_cell_renderer_text_new();
+	cell_text = gtk_cell_renderer_text_new ();
 
 	cell_right_aligned = gtk_cell_renderer_text_new ();
 	g_object_set (cell_right_aligned, "xalign", 1.0, NULL);
@@ -176,6 +197,14 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_VSZ]);
 
+	g_object_get (treeview->settings, "column-group-vsz", &visible, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Group VSZ"), cell_right_aligned, "text", XTM_PTV_COLUMN_GROUP_VSZ_STR, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
+	g_object_set (column, COLUMN_PROPERTIES, NULL);
+	g_object_set_data (G_OBJECT (column), "sort-column-id", GINT_TO_POINTER (XTM_PTV_COLUMN_GROUP_VSZ));
+	g_object_set_data (G_OBJECT (column), "column-id", GINT_TO_POINTER (COLUMN_GROUP_VSZ));
+	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
+	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_GROUP_VSZ]);
+
 	g_object_get (treeview->settings, "column-rss", &visible, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("RSS"), cell_right_aligned, "text", XTM_PTV_COLUMN_RSS_STR, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
 	g_object_set (column, COLUMN_PROPERTIES, NULL);
@@ -184,6 +213,14 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_RSS]);
 
+	g_object_get (treeview->settings, "column-group-rss", &visible, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Group RSS"), cell_right_aligned, "text", XTM_PTV_COLUMN_GROUP_RSS_STR, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
+	g_object_set (column, COLUMN_PROPERTIES, NULL);
+	g_object_set_data (G_OBJECT (column), "sort-column-id", GINT_TO_POINTER (XTM_PTV_COLUMN_GROUP_RSS));
+	g_object_set_data (G_OBJECT (column), "column-id", GINT_TO_POINTER (COLUMN_GROUP_RSS));
+	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
+	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_GROUP_RSS]);
+
 	g_object_get (treeview->settings, "column-uid", &visible, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("UID"), cell_text, "text", XTM_PTV_COLUMN_UID_STR, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
 	g_object_set (column, COLUMN_PROPERTIES, NULL);
@@ -200,6 +237,14 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_CPU]);
 
+	g_object_get (treeview->settings, "column-group-cpu", &visible, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Group CPU"), cell_right_aligned, "text", XTM_PTV_COLUMN_GROUP_CPU_STR, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
+	g_object_set (column, COLUMN_PROPERTIES, NULL);
+	g_object_set_data (G_OBJECT (column), "sort-column-id", GINT_TO_POINTER (XTM_PTV_COLUMN_GROUP_CPU));
+	g_object_set_data (G_OBJECT (column), "column-id", GINT_TO_POINTER (COLUMN_GROUP_CPU));
+	g_signal_connect (column, "clicked", G_CALLBACK (column_clicked), treeview);
+	gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview), column, treeview->columns_positions[COLUMN_GROUP_CPU]);
+
 	g_object_get (treeview->settings, "column-priority", &visible, NULL);
 	/* TRANSLATORS: “Prio.” is short for Priority, it appears in the tree view header. */
 	column = gtk_tree_view_column_new_with_attributes (_("Prio."), cell_right_aligned, "text", XTM_PTV_COLUMN_PRIORITY, "cell-background", XTM_PTV_COLUMN_BACKGROUND, "foreground", XTM_PTV_COLUMN_FOREGROUND, NULL);
@@ -259,6 +304,9 @@ xtm_process_tree_view_finalize (GObject *object)
 		g_object_unref (treeview->settings);
 	}
 
+	g_free (treeview->cmd_filter);
+	treeview->cmd_filter = NULL;
+
 	G_OBJECT_CLASS (xtm_process_tree_view_parent_class)->finalize (object);
 }
 
@@ -317,24 +365,46 @@ columns_changed (XtmProcessTreeView *treeview)
 static void
 read_columns_positions (XtmProcessTreeView *treeview)
 {
-	gushort i;
 	gchar *columns_positions;
-	gchar **columns_positions_split;
+	gboolean valid_setting;
 
 	g_object_get (treeview->settings, "columns-positions", &columns_positions, NULL);
+	valid_setting = columns_positions != NULL;
 
-	if (columns_positions == NULL)
+	if (valid_setting)
 	{
-		for (i = 0; i < N_COLUMNS; i++)
-			treeview->columns_positions[i] = i;
-	}
-	else
-	{
-		columns_positions_split = g_strsplit (columns_positions, ";", N_COLUMNS + 1);
-		for (i = 0; i < N_COLUMNS && columns_positions_split[i] != NULL; i++)
-			treeview->columns_positions[i] = (gushort)g_ascii_strtoll (columns_positions_split[i], NULL, 10);
+		gchar **columns_positions_split = g_strsplit (columns_positions, ";", -1);
+		valid_setting = g_strv_length (columns_positions_split) == N_COLUMNS + 1;
+		if (valid_setting)
+		{
+			for (gint i = 0; i < N_COLUMNS; i++)
+			{
+				gchar *end;
+				gushort position = g_ascii_strtoull (columns_positions_split[i], &end, 10);
+				if (*end != '\0' || position >= N_COLUMNS)
+				{
+					valid_setting = FALSE;
+					break;
+				}
+
+				treeview->columns_positions[i] = position;
+			}
+		}
 		g_strfreev (columns_positions_split);
 		g_free (columns_positions);
+
+		if (!valid_setting)
+		{
+			XfconfChannel *channel = xfconf_channel_get (CHANNEL);
+			g_warning ("Invalid list of column positions, reset Xfconf property /columns/positions");
+			xfconf_channel_reset_property (channel, "/columns/positions", TRUE);
+		}
+	}
+
+	if (!valid_setting)
+	{
+		for (gint i = 0; i < N_COLUMNS; i++)
+			treeview->columns_positions[i] = i;
 	}
 }
 
@@ -347,7 +417,7 @@ save_columns_positions (XtmProcessTreeView *treeview)
 	gchar columns_positions[COLUMNS_POSITIONS_STRLEN] = { 0 };
 
 	for (i = 0; i < N_COLUMNS; i++)
-		offset += (gulong)g_snprintf (&columns_positions[offset], (sizeof(columns_positions) - offset), "%d;", treeview->columns_positions[i]);
+		offset += (gulong)g_snprintf (&columns_positions[offset], (sizeof (columns_positions) - offset), "%d;", treeview->columns_positions[i]);
 
 	g_object_set (treeview->settings, "columns-positions", columns_positions, NULL);
 }
@@ -387,7 +457,8 @@ cb_send_signal (GtkMenuItem *mi, gpointer user_data)
 			_("Error sending signal"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 			_("An error was encountered by sending a signal to the PID %d. "
-			"It is likely you don't have the required privileges."), pid);
+				"It is likely you don't have the required privileges."),
+			pid);
 		gtk_window_set_title (GTK_WINDOW (dialog), _("Task Manager"));
 		gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -416,8 +487,10 @@ cb_set_priority (GtkMenuItem *mi, gpointer user_data)
 	{
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 			_("Error setting priority"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), _("An error was encountered by setting a priority to the PID %d. "
-			"It is likely you don't have the required privileges."), pid);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("An error was encountered by setting a priority to the PID %d. "
+				"It is likely you don't have the required privileges."),
+			pid);
 		gtk_window_set_title (GTK_WINDOW (dialog), _("Task Manager"));
 		gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -460,6 +533,7 @@ cb_copy_command_line (GtkMenuItem *mi, gpointer user_data)
 
 			clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 			gtk_clipboard_set_text (clipboard, cmdline, -1);
+			g_free (cmdline);
 
 			keep_looking = FALSE;
 		}
@@ -540,7 +614,7 @@ build_context_menu (XtmProcessTreeView *treeview, GPid pid)
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_copy_command_line), treeview);
 	/* Refer to treeview_key_pressed to see how the Ctrl-c press is handled */
 	accel_label = gtk_bin_get_child (GTK_BIN (mi));
-	gtk_accel_label_set_accel(GTK_ACCEL_LABEL (accel_label), GDK_KEY_c, GDK_CONTROL_MASK);
+	gtk_accel_label_set_accel (GTK_ACCEL_LABEL (accel_label), GDK_KEY_c, GDK_CONTROL_MASK);
 
 	gtk_widget_show_all (menu);
 
@@ -615,7 +689,7 @@ treeview_key_pressed (XtmProcessTreeView *treeview, GdkEventKey *event)
 		GdkWindow *window = gtk_tree_view_get_bin_window (GTK_TREE_VIEW (treeview));
 
 		gtk_menu_popup_at_rect (GTK_MENU (create_popup_menu (treeview, pid, event->time)),
-								window, &rect, GDK_GRAVITY_NORTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
+			window, &rect, GDK_GRAVITY_NORTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
 		return TRUE;
 	}
 	else if (event->keyval == GDK_KEY_Delete)
@@ -670,17 +744,17 @@ column_clicked (GtkTreeViewColumn *column, XtmProcessTreeView *treeview)
 
 	treeview->sort_column = column;
 
-	g_object_set(treeview->settings,
-	    "sort-column-id", GPOINTER_TO_INT(g_object_get_data(G_OBJECT(treeview->sort_column), "column-id")),
-	    "sort-type", sort_type,
-	    NULL);
+	g_object_set (treeview->settings,
+		"sort-column-id", GPOINTER_TO_INT (g_object_get_data (G_OBJECT (treeview->sort_column), "column-id")),
+		"sort-type", sort_type,
+		NULL);
 }
 
 void
-xtm_process_tree_view_set_filter(XtmProcessTreeView *treeview, const gchar *cmd_filter)
+xtm_process_tree_view_set_filter (XtmProcessTreeView *treeview, const gchar *cmd_filter)
 {
-	g_free(treeview->cmd_filter);
-	treeview->cmd_filter = g_strdup(cmd_filter);
+	g_free (treeview->cmd_filter);
+	treeview->cmd_filter = g_strdup (cmd_filter);
 
 	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (treeview->model_filter));
 }
@@ -689,12 +763,14 @@ static gboolean
 visible_func (GtkTreeModel *model, GtkTreeIter *iter, XtmProcessTreeView *treeview)
 {
 	gchar *cmdline, *cmdline_lower, *key_lower, *p = NULL;
-	gboolean  mach_filter = TRUE, match_uid = TRUE;
+	gboolean mach_filter = TRUE, match_uid = TRUE;
 	guint uid;
 
-	if(treeview->cmd_filter) {
+	if (treeview->cmd_filter)
+	{
 		gtk_tree_model_get (GTK_TREE_MODEL (model), iter, XTM_PTV_COLUMN_COMMAND, &cmdline, -1);
-		if(cmdline) {
+		if (cmdline)
+		{
 			cmdline_lower = g_ascii_strdown (cmdline, -1);
 			key_lower = g_ascii_strdown (treeview->cmd_filter, -1);
 
@@ -705,10 +781,11 @@ visible_func (GtkTreeModel *model, GtkTreeIter *iter, XtmProcessTreeView *treevi
 			g_free (cmdline);
 		}
 
-		if(!p)
+		if (!p)
 			mach_filter = FALSE;
 	}
-	if (!treeview->show_all_processes_cached) {
+	if (!treeview->show_all_processes_cached)
+	{
 		gtk_tree_model_get (GTK_TREE_MODEL (treeview->model), iter, XTM_PTV_COLUMN_UID, &uid, -1);
 		if (treeview->owner_uid != uid)
 			match_uid = FALSE;
@@ -754,10 +831,16 @@ settings_changed (GObject *object, GParamSpec *pspec, XtmProcessTreeView *treevi
 			column_id = COLUMN_STATE;
 		else if (!g_strcmp0 (pspec->name, "column-vsz"))
 			column_id = COLUMN_VSZ;
+		else if (!g_strcmp0 (pspec->name, "column-group-vsz"))
+			column_id = COLUMN_GROUP_VSZ;
 		else if (!g_strcmp0 (pspec->name, "column-rss"))
 			column_id = COLUMN_RSS;
+		else if (!g_strcmp0 (pspec->name, "column-group-rss"))
+			column_id = COLUMN_GROUP_RSS;
 		else if (!g_strcmp0 (pspec->name, "column-cpu"))
 			column_id = COLUMN_CPU;
+		else if (!g_strcmp0 (pspec->name, "column-group-cpu"))
+			column_id = COLUMN_GROUP_CPU;
 		else if (!g_strcmp0 (pspec->name, "column-priority"))
 			column_id = COLUMN_PRIORITY;
 
@@ -815,14 +898,15 @@ xtm_process_tree_view_get_model (XtmProcessTreeView *treeview)
 }
 
 void
-xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, GPid pid) {
-	GtkTreeModel	*model;
-	GtkTreePath		*path;
-	GtkTreeIter 	 iter;
-	gboolean     	 valid;
-	gboolean			 tree;
-	GPid		pid_iter;
-	GtkTreeIter	child_iter;
+xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, GPid pid)
+{
+	GtkTreeModel *model;
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	gboolean valid;
+	gboolean tree;
+	GPid pid_iter;
+	GtkTreeIter child_iter;
 	gboolean validParent;
 
 	g_object_get (treeview->settings, "process-tree", &tree, NULL);
@@ -850,7 +934,7 @@ xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, GPid pid) {
 
 		if (gtk_tree_model_iter_has_child (model, &iter))
 		{
-			GtkTreeIter	parent_iter = iter;
+			GtkTreeIter parent_iter = iter;
 
 			valid = gtk_tree_model_iter_children (model, &iter, &parent_iter);
 		}
@@ -860,8 +944,9 @@ xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, GPid pid) {
 			valid = gtk_tree_model_iter_next (model, &iter);
 			if (tree && !valid)
 			{
-				//finding my way up again
-				do {
+				// finding my way up again
+				do
+				{
 					validParent = gtk_tree_model_iter_parent (model, &iter, &child_iter);
 					child_iter = iter;
 					valid = gtk_tree_model_iter_next (model, &iter);
