@@ -10,13 +10,9 @@
 #ifndef SETTINGS_DIALOG_H
 #define SETTINGS_DIALOG_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-void		xtm_settings_dialog_run				(GtkWidget *parent_window);
+void xtm_settings_dialog_run (GtkWidget *parent_window);
 
 #endif /* !SETTINGS_DIALOG_H */
